@@ -168,6 +168,7 @@ private:
     QTreeView *fileView; ///< file explorer in docks
     QFileSystemModel *fileExplorerModel = nullptr;
 	QString hiddenLeftPanelWidgets;
+    QString docksToBeRaised; ///< when restoring docks from hidden sidepanel, these docks should be raised. Dock names are separated by "|"
     QMap<QString, QString> m_dockIcons;
     QList<QDockWidget*> m_docksOrder;
 
@@ -746,6 +747,8 @@ public slots:
     void addDock(const QString &name, const QString &iconName, const QString &title, QWidget *wgt);
     void toggleDocks(bool visible);
     void resetDocks();
+    void toggleDockVisibility();
+    void updateDockVisibility(bool visible);
 
 signals:
 	void infoNewFile(); ///< signal that a new file has been generated. Used for scritps as trigger.
